@@ -1,4 +1,4 @@
-__version__ = "0.1"
+__version__ = "0.1.1"
 __all__ = []
 
 from pyiron_atomistics.project import Project
@@ -6,6 +6,7 @@ from pyiron_base import Notebook, install_dialog, JOB_CLASS_DICT
 
 # Make classes available for new pyiron version
 JOB_CLASS_DICT['ElasticMatrixJob'] = 'pyiron_gpl.elastic.elastic'
+JOB_CLASS_DICT['PaceMakerJob'] = 'pyiron_gpl.pacemaker.pacemaker'
 
 from ._version import get_versions
 
